@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "job.h"
@@ -128,11 +114,11 @@ QString Job::Private::parseErrorMessage(const QByteArray &json)
         QVariantMap map = document.toVariant().toMap();
         QString message;
 
-        if (map.contains(QLatin1String("error"))) {
+        if (map.contains(QStringLiteral("error"))) {
             map = map.value(QStringLiteral("error")).toMap();
         }
 
-        if (map.contains(QLatin1String("message"))) {
+        if (map.contains(QStringLiteral("message"))) {
             message.append(map.value(QStringLiteral("message")).toString());
         } else {
             message = QLatin1String(json);
