@@ -1,21 +1,7 @@
 /*
-    Copyright (C) 2012  Jan Grulich <grulja@gmail.com>
+    SPDX-FileCopyrightText: 2012 Jan Grulich <grulja@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 
@@ -108,28 +94,28 @@ LocationPtr Private::parseLocation(const QVariantMap &map)
 {
     LocationPtr location(new Location);
 
-    if (map.contains(QLatin1String("timestampMs"))) {
+    if (map.contains(QStringLiteral("timestampMs"))) {
         location->setTimestamp(map.value(QStringLiteral("timestampMs")).toULongLong());
     }
-    if (map.contains(QLatin1String("latitude"))) {
+    if (map.contains(QStringLiteral("latitude"))) {
         location->setLatitude(map.value(QStringLiteral("latitude")).toFloat());
     }
-    if (map.contains(QLatin1String("longitude"))) {
+    if (map.contains(QStringLiteral("longitude"))) {
         location->setLongitude(map.value(QStringLiteral("longitude")).toFloat());
     }
-    if (map.contains(QLatin1String("accuracy"))) {
+    if (map.contains(QStringLiteral("accuracy"))) {
         location->setAccuracy(map.value(QStringLiteral("accuracy")).toInt());
     }
-    if (map.contains(QLatin1String("speed"))) {
+    if (map.contains(QStringLiteral("speed"))) {
         location->setSpeed(map.value(QStringLiteral("speed")).toInt());
     }
-    if (map.contains(QLatin1String("heading"))) {
+    if (map.contains(QStringLiteral("heading"))) {
         location->setHeading(map.value(QStringLiteral("heading")).toInt());
     }
-    if (map.contains(QLatin1String("altitude"))) {
+    if (map.contains(QStringLiteral("altitude"))) {
         location->setAltitude(map.value(QStringLiteral("altitude")).toInt());
     }
-    if (map.contains(QLatin1String("altitudeAccuracy"))) {
+    if (map.contains(QStringLiteral("altitudeAccuracy"))) {
         location->setAltitudeAccuracy(map.value(QStringLiteral("altitudeAccuracy")).toInt());
     }
 
